Non-responsive Template for Bootstrap

# Non-responsive Bootstrap

Disable the responsiveness of Bootstrap by fixing the width of the container and using the first grid system tier.

### What changes

Note the lack of the `<meta name="viewport" content="width=device-width, initial-scale=1.0">`, which disables the zooming aspect of sites in mobile devices. In addition, we reset our container's width and are basically good to go.

### Regarding navbars

As a heads up, the navbar component is rather tricky here in that the styles for displaying it are rather specific and detailed. Overrides to ensure desktop styles display are not as performant or sleek as one would like. Just be aware there may be potential gotchas as you build on top of this example when using the navbar.

### Non-responsive grid system

One third
One third
One third